## ----echo = FALSE-------------------------------------------------------------
library("DT")
library("epiparameterDB")

tbl <- lapply(epiparameterDB::epiparameterDB, function(x) {
  data.frame(
    disease = x$disease,
    pathogen = x$pathogen,
    epi_name = x$epi_name,
    citation_info = paste0(
      epiparameterDB:::.cite_author(x), # nolint undesirable_operator_linter
      "(", x$citation$year, ")",
      ", DOI: ",
      "<a href=\"https://doi.org/", x$citation$doi, "\">",
      x$citation$doi, "</a>"
    )
  )
})
tb <- do.call(rbind, tbl)
## sort by disease then pathogen
tb <- tb[order(tb$disease, tb$pathogen), ]
datatable(
  tb,
  rownames = FALSE,
  colnames = c("Disease", "Pathogen", "Distribution", "Reference"),
  escape = FALSE,
  options = list(pageLength = 50)
)

